package common;

import java.util.HashMap;

/**
 * This class fixes a flaw in the design of java.util.HashMap:
 * Allowing arbitrary objects as arguments of {@link HashMap#get(Object)},
 * {@link HashMap#contains(Object)} and {@link HashMap#remove(Object)}
 * prevents the type checker from detecting inconsistent usage.<br>
 * Instead of these unsafe methods the new versions introduced in this 
 * class should be used.
 */
public class TypeSafeMap<K,V> extends HashMap<K, V> {
	private static final long serialVersionUID = -216745921347261689L;
	
	public V safeGet(K key) {
		return get(key);
	}
	
	public boolean safeContainsKey(K key) {
		return containsKey(key);
	}
	
	public V safeRemove(K key) {
		return remove(key);
	}
}
