package common;

import java.util.HashSet;

/**
 * This class fixes a flaw in the design of java.util.HashSet:
 * Allowing arbitrary objects as arguments of {@link HashSet#contains(Object)} 
 * and {@link HashSet#remove(Object)} prevents the type checker from detecting
 * inconsistent usage. <br>
 * Instead of these unsafe methods the new versions introduced in this class
 * should be used.
 */
public class TypeSafeSet<T> extends HashSet<T> {
	private static final long serialVersionUID = 1646797305723499556L;

	public boolean safeContains(T element) {
		return contains(element);
	}
	
	public boolean safeRemove(T value) {
		return remove(value);
	}
}
